@@ -2,7 +2,7 @@ BINSEG = function(sumstat, pen = 0, cost_func = "norm.mean", shape = 1, minsegle
   
   n=length(sumstat[,1])-1
   if(n<2){stop('Data must have atleast 2 observations to fit a changepoint model.')}
-  if(Q>((n/2)+1)){stop(paste('Q is larger than the maximum number of segments',(n/2)+1))}
+  if(Q>((n/2)+1)){stop(paste('Q is larger than the maximum number of segments',floor(n/2)+1))}
   if(Q<=0){stop(paste('Q is the maximum number of changepoints so should be greater than 0'))}
   
   storage.mode(sumstat) = 'double'
